"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apollo_client_1 = require("apollo-client");
const apollo_link_http_1 = require("apollo-link-http");
const apollo_cache_inmemory_1 = require("apollo-cache-inmemory");
class Apollo {
    constructor(uri, options) {
        this.desc = "A endpoint used for APIv4 requests";
        this.headers = options.headers;
        const fragmentMatcher = new apollo_cache_inmemory_1.IntrospectionFragmentMatcher({
            introspectionQueryResultData: {
                __schema: {
                    types: [],
                },
            },
        });
        try {
            this.cache = new apollo_cache_inmemory_1.InMemoryCache({ fragmentMatcher });
        }
        catch {
            throw new Error("An error occurred while initializing the cache!");
        }
        try {
            this.link = new apollo_link_http_1.HttpLink({
                uri,
                headers: options.headers,
            });
        }
        catch {
            throw new Error("An error occurred while initializing the API link!");
        }
        try {
            this.client = new apollo_client_1.ApolloClient({
                cache: this.cache,
                link: this.link,
            });
        }
        catch {
            throw new Error("An error occurred while initializing the headers!");
        }
    }
    async sendQuery(data, variables, headers) {
        return this.client.query({
            query: data,
            errorPolicy: "all",
            fetchPolicy: "network-only",
            variables,
            context: {
                headers: { ...this.headers, ...headers },
            },
        });
    }
    async sendMutation(data, variables, headers) {
        return this.client.mutate({
            mutation: data,
            errorPolicy: "all",
            variables,
            context: {
                headers: { ...this.headers, ...headers },
            },
        });
    }
}
exports.default = Apollo;
