"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebClient = exports.GithubClient = exports.SnekClient = void 0;
const apollo_1 = __importDefault(require("./endpoints/apollo"));
const scraper_1 = __importDefault(require("./endpoints/scraper"));
const index_1 = require("./templates/index");
const sessions_1 = require("./session/sessions");
class Client {
    constructor(ep) {
        ep.url = ((url) => {
            if (!/^(?:f|ht)tps?\:\/\//.test(url)) {
                url = "http://" + url;
            }
            return url;
        })(ep.url);
    }
}
class SnekClient extends Client {
    constructor(url = "https://engine.snek.at/api/graphiql", headers = {}, type = "graphql") {
        super({ type, url, headers });
        this.template = new index_1.MainTemplate();
        this.gql = new apollo_1.default(url, { headers });
        this.session = new sessions_1.SnekSession("snek", this.gql, this.template.snek);
    }
}
exports.SnekClient = SnekClient;
class GithubClient extends Client {
    constructor(url = "https://api.github.com/graphql", headers = {}, type = "graphql") {
        super({ type, url, headers });
        this.template = new index_1.MainTemplate();
        this.gql = new apollo_1.default(url, { headers });
        this.session = new sessions_1.GithubSession("github", this.gql, this.template);
    }
}
exports.GithubClient = GithubClient;
class WebClient extends Client {
    constructor(url, headers = {}, type = "A webscraper client") {
        super({ type, url, headers });
        this.scraper = new scraper_1.default(url, { headers });
    }
}
exports.WebClient = WebClient;
