"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SnekSession = exports.GithubSession = void 0;
const js_cookie_1 = __importDefault(require("js-cookie"));
const index_1 = __importDefault(require("./index"));
const index_2 = __importDefault(require("../templates/snek/gql/tasks/index"));
class GithubSession extends index_1.default {
    constructor(sId, ep, template) {
        super(sId);
        this.ep = ep;
        this.template = template;
    }
    async send(token, data, variables) {
        let headers = {
            authorization: token,
        };
        return this.ep.sendQuery(data, variables, headers);
    }
}
exports.GithubSession = GithubSession;
class SnekSession extends index_1.default {
    constructor(sId, ep, template) {
        super(sId);
        this.ep = ep;
        this.template = template;
        this.refreshTokenName = "refresh";
        this.tokenName = sId + "-" + this.tokenName;
        this.refreshTokenName = sId + "-" + this.refreshTokenName;
        this.tasks = new index_2.default(this);
    }
    get token() {
        return super.token;
    }
    get refreshToken() {
        const token = js_cookie_1.default.get(this.refreshTokenName);
        return token ? token : undefined;
    }
    set token(value) {
        if (value) {
            js_cookie_1.default.set(this.tokenName, value ? value : "", {
                expires: 4 / 1440,
            });
        }
        else {
            js_cookie_1.default.remove(this.tokenName);
        }
    }
    set refreshToken(value) {
        if (value) {
            js_cookie_1.default.set(this.refreshTokenName, value, {
                expires: 6,
            });
        }
        else {
            js_cookie_1.default.remove(this.refreshTokenName);
        }
    }
    async upToDateToken() {
        let token = super.token;
        if (!token) {
            await this.refresh();
            token = super.token;
        }
        return token;
    }
    async send(token, data, variables) {
        let headers = {
            authorization: token,
        };
        return this.ep.sendQuery(data, variables, headers);
    }
    async begin(user) {
        let response;
        if (!user && this.refreshToken) {
            this.refresh();
        }
        else {
            if (!user) {
                response = await this.tasks.auth.anon();
            }
            else {
                response = await this.tasks.auth.nonanon(user);
            }
            this.token = response.data?.auth.token;
            this.refreshToken = response.data?.auth.refreshToken;
            return response.data?.auth.user;
        }
        response = await this.tasks.user.whoami();
        return response.data?.whoami;
    }
    async refresh() {
        if (!this.token) {
            if (this.refreshToken) {
                let response = await this.tasks.auth.refresh();
                this.token = response.data?.refresh.token;
                this.refreshToken = response.data?.refresh.refreshToken;
            }
            else {
                await this.begin();
            }
        }
    }
    async end() {
        if (this.refreshToken !== "") {
            let response = await this.tasks.auth.revoke();
        }
        this.token = undefined;
        this.refreshToken = undefined;
    }
    async customTask(type, data, variables) {
        return this.tasks.run(type, data, {
            ...variables,
            token: this.token,
            refreshToken: this.refreshToken,
        });
    }
}
exports.SnekSession = SnekSession;
